pub struct TestOpts {
pub filter: Option<String>,
pub run_ignored: bool,
pub logfile: Option<PathBuf>,
pub quiet: bool,
pub test_threads: Option<usize>,
}
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.